"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.FormActionBuilder = void 0;
var redux_effects_promise_1 = require("redux-effects-promise");
var util_1 = require("../util");
var definition_1 = require("../definition");
/**
 * @action-builder
 * @stable [08.09.2020]
 */
var FormActionBuilder = /** @class */ (function () {
    function FormActionBuilder() {
    }
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildDestroyActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_DESTROY_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildClearActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_CLEAR_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildChangeActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_CHANGE_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildDefaultChangeActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_DEFAULT_CHANGE_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildResetActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_RESET_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildValidActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_VALID_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildActiveValueActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_ACTIVE_VALUE_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildInactiveValueActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_INACTIVE_VALUE_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildSubmitActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_SUBMIT_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildProgressActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_PROGRESS_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildSubmitDoneActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_SUBMIT_DONE_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildSubmitFinishActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_SUBMIT_FINISH_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildSubmitErrorActionType = function (section) {
        return util_1.SectionUtils.actionPrefix(section) + "." + definition_1.FORM_SUBMIT_ERROR_ACTION_TYPE;
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildSubmitDoneAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildSubmitDoneActionType(section), util_1.SectionUtils.applySection(section));
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildResetAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildResetActionType(section), util_1.SectionUtils.applySection(section));
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildProgressAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildProgressActionType(section), util_1.SectionUtils.applySection(section));
    };
    /**
     * @stable [03.02.2020]
     * @param {string} section
     * @param {boolean} valid
     * @returns {IEffectsAction}
     */
    FormActionBuilder.buildValidAction = function (section, valid) {
        var plainAction = this.buildValidPlainAction(section, valid);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildSubmitFinishAction = function (section) {
        var plainAction = this.buildSubmitFinishPlainAction(section);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildDestroyAction = function (section) {
        return redux_effects_promise_1.EffectsAction.create(this.buildDestroyActionType(section), util_1.SectionUtils.applySection(section));
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param fieldName
     */
    FormActionBuilder.buildClearAction = function (section, fieldName) {
        var plainAction = this.buildClearPlainAction(section, fieldName);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param changes
     */
    FormActionBuilder.buildChangesAction = function (section, changes) {
        var plainAction = this.buildChangesPlainAction(section, changes);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param changes
     */
    FormActionBuilder.buildDefaultChangesAction = function (section, changes) {
        var plainAction = this.buildDefaultChangesPlainAction(section, changes);
        return redux_effects_promise_1.EffectsAction.create(plainAction.type, plainAction.data);
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param fieldName
     */
    FormActionBuilder.buildClearPlainAction = function (section, fieldName) {
        var _a;
        return {
            type: this.buildClearActionType(section),
            data: util_1.SectionUtils.applySection(section, this.buildChangesPayload((_a = {}, _a[fieldName] = definition_1.FieldConstants.VALUE_TO_CLEAR_DIRTY_CHANGES, _a))),
        };
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildResetPlainAction = function (section) {
        return { type: this.buildResetActionType(section), data: util_1.SectionUtils.applySection(section) };
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param apiEntity
     */
    FormActionBuilder.buildSubmitPlainAction = function (section, apiEntity) {
        return { type: this.buildSubmitActionType(section), data: util_1.SectionUtils.applySection(section, apiEntity) };
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param valid
     */
    FormActionBuilder.buildValidPlainAction = function (section, valid) {
        var fluxEntity = { valid: valid };
        return { type: this.buildValidActionType(section), data: util_1.SectionUtils.applySection(section, fluxEntity) };
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param payload
     */
    FormActionBuilder.buildActiveValuePlainAction = function (section, payload) {
        var fluxEntity = { payload: payload };
        return { type: this.buildActiveValueActionType(section), data: util_1.SectionUtils.applySection(section, fluxEntity) };
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param payload
     */
    FormActionBuilder.buildInactiveValuePlainAction = function (section, payload) {
        var fluxEntity = { payload: payload };
        return { type: this.buildInactiveValueActionType(section), data: util_1.SectionUtils.applySection(section, fluxEntity) };
    };
    /**
     * @stable [08.09.2020]
     * @param section
     */
    FormActionBuilder.buildSubmitFinishPlainAction = function (section) {
        return { type: this.buildSubmitFinishActionType(section), data: util_1.SectionUtils.applySection(section) };
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param changes
     */
    FormActionBuilder.buildChangesPlainAction = function (section, changes) {
        return {
            type: this.buildChangeActionType(section),
            data: util_1.SectionUtils.applySection(section, this.buildChangesPayload(changes)),
        };
    };
    /**
     * @stable [08.09.2020]
     * @param section
     * @param changes
     */
    FormActionBuilder.buildDefaultChangesPlainAction = function (section, changes) {
        return {
            type: this.buildDefaultChangeActionType(section),
            data: util_1.SectionUtils.applySection(section, this.buildChangesPayload(changes)),
        };
    };
    /**
     * @stable [08.09.2020]
     * @param fields
     * @private
     */
    FormActionBuilder.buildChangesPayload = function (fields) {
        return { fields: fields };
    };
    return FormActionBuilder;
}());
exports.FormActionBuilder = FormActionBuilder;
//# sourceMappingURL=form-action.builder.js.map