/// <reference types="react" />
import { AnyT, StringNumberT } from '../../../definitions.interface';
import { DateFieldRangeValueT, DateTimeLikeTypeT, IBaseEvent, IDatesRangeEntity } from '../../../definition';
import { IDateFieldProps, IDateFieldState } from './date-field.interface';
import { BaseTextField } from '../text-field/base-text-field.component';
export declare class DateField extends BaseTextField<IDateFieldProps, IDateFieldState> {
    static readonly defaultProps: IDateFieldProps & Partial<import("../../../definition").IGenericComponentProps<any>>;
    private static readonly INITIAL_PERIOD_DATE_VALUE;
    private static readonly INITIAL_PERIOD_STATE;
    private static readonly INITIAL_RANGE_TO_DATE_STATE;
    private static readonly INITIAL_RANGE_PERIOD_STATE;
    private static readonly DEFAULT_RANGE_PERIOD_STATE;
    private readonly defaultRangeFieldProps;
    private readonly dialogRef;
    private readonly fromDateRef;
    /**
     * @stable [07.01.2020]
     * @param {IDateFieldProps} props
     */
    constructor(props: IDateFieldProps);
    /**
     * @stable [26.03.2020]
     * @returns {JSX.Element}
     */
    render(): JSX.Element;
    /**
     * @stable [07.03.2020]
     * @param {IDatesRangeEntity | DateTimeLikeTypeT | AnyT} currentRawValue
     */
    onChangeManually(currentRawValue: IDatesRangeEntity | DateTimeLikeTypeT | AnyT): void;
    /**
     * @stable [09.01.2020]
     * @returns {JSX.Element}
     */
    protected get attachmentElement(): JSX.Element;
    /**
     * @stable [07.03.2020]
     * @returns {StringNumberT[] | string}
     */
    protected get originalEmptyValue(): StringNumberT[] | string;
    /**
     * @stable [07.03.2020]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [26.03.2020]
     * @param {DateFieldRangeValueT} value
     * @returns {string}
     */
    protected decorateDisplayValue(value: DateFieldRangeValueT): string;
    /**
     * @stable [09.03.2020]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [09.03.2020]
     * @returns {string}
     */
    protected getFieldPattern(): string;
    /**
     * @stable [09.03.2020]
     * @returns {Array<string | RegExp>}
     */
    protected getFieldMask(): (string | RegExp)[];
    /**
     * @stable [09.03.2020]
     * @returns {string}
     */
    protected get fieldFormat(): string;
    /**
     * @stable [25.03.2020]
     * @returns {JSX.Element}
     */
    private get calendarAttachmentElement();
    /**
     * @stable [20.01.2020]
     * @returns {JSX.Element}
     */
    private get calendarElement();
    /**
     * @stable [21.01.2020]
     * @returns {ICalendarProps}
     */
    private get defaultCalendarProps();
    /**
     * @stable [20.01.2020]
     * @returns {React.ReactNode}
     */
    private get rangeExplorerDateElement();
    /**
     * @stable [20.01.2020]
     * @returns {JSX.Element}
     */
    private get dateFieldsElement();
    /**
     * @stable [24.03.2020]
     * @returns {DateTimeLikeTypeT}
     */
    private get toDateFieldValue();
    /**
     * @stable [25.03.2020]
     * @returns {DateTimeLikeTypeT}
     */
    private get fromDateFieldValue();
    /**
     * @stable [25.03.2020]
     * @returns {JSX.Element}
     */
    private get previousQuickButtonsElement();
    /**
     * @stable [07.03.2020]
     * @returns {JSX.Element}
     */
    private get quickButtonsElement();
    /**
     * @stable [25.03.2020]
     */
    private subtractPeriod;
    /**
     * @stable [25.03.2020]
     */
    private addPeriod;
    /**
     * @stable [26.03.2020]
     * @param {number} duration
     */
    private doChangePeriod;
    /**
     * @stable [25.03.2020]
     * @param {DatePeriodsEnum} period
     * @param {boolean} isPreviousPeriodModeEnabled
     * @returns {string}
     */
    private getQuickActionClassName;
    /**
     * @stable [07.03.2020]
     */
    private onSetDay;
    /**
     * @stable [25.03.2020]
     */
    private onSetYesterday;
    /**
     * @stable [07.03.2020]
     */
    private onSetWeek;
    /**
     * @stable [25.03.2020]
     */
    private onSetLastWeek;
    /**
     * @stable [07.03.2020]
     */
    private onSetMonth;
    /**
     * @stable [25.03.2020]
     */
    private onSetLastMonth;
    /**
     * @stable [08.03.2020]
     */
    private onSetQuarter;
    /**
     * @stable [25.03.2020]
     */
    private onSetLastQuarter;
    /**
     * @stable [08.03.2020]
     */
    private onSetCustom;
    /**
     * @stable [06.03.2020]
     * @param {Date} from
     * @param {Date} to
     * @param {DatePeriodsEnum} periodMode
     */
    private setQuickValue;
    /**
     * @stable [11.03.2020]
     */
    private setFromDateFocus;
    /**
     * @stable [07.03.2020]
     */
    private setPreviousMonth;
    /**
     * @stable [07.03.2020]
     */
    private setNextMonth;
    /**
     * @stable [07.03.2020]
     * @param {number} duration
     */
    private doChangeMonth;
    /**
     * @stable [25.03.2020]
     * @param {string} value
     */
    private onToDateFieldChange;
    /**
     * @stable [25.03.2020]
     * @param {string} value
     */
    private onFromDateFieldChange;
    /**
     * @stable [10.03.2020]
     */
    private onAccept;
    /**
     * @stable [25.03.2020]
     * @param {ICalendarDayEntity} calendarDayEntity
     */
    private onDaySelect;
    /**
     * @stable [08.03.2020]
     */
    private onDialogDeactivate;
    /**
     * @stable [08.03.2020]
     * @param {() => void} callback
     */
    private onDialogClose;
    /**
     * @stable [08.03.2020]
     */
    private openDialog;
    /**
     * @stable [09.03.2020]
     * @param {IDatesRangeEntity} dateRangeEntity
     * @returns {string}
     */
    private getDecoratedRangeDisplayValue;
    /**
     * @stable [09.03.2020]
     * @param {DateTimeLikeTypeT} from
     * @param {DateTimeLikeTypeT} to
     * @param {string} label
     * @returns {string}
     */
    private getDecoratedRangeSpecificValue;
    /**
     * @stable [24.03.2020]
     * @returns {string}
     */
    private get previousPeriodQuickActionText();
    /**
     * @stable [09.03.2020]
     * @param {string} dateFromAsString
     * @param {string} dateToAsString
     * @param {Date} dateFrom
     * @param {Date} dateTo
     * @returns {boolean}
     */
    private checkRange;
    /**
     * @stable [08.03.2020]
     * @param {DateTimeLikeTypeT} value
     * @returns {string}
     */
    private serializeValue;
    /**
     * @stable [08.03.2020]
     * @returns {string}
     */
    private get currentDateAsDisplayValue();
    /**
     * @stable [08.03.2020]
     * @returns {string}
     */
    private get nextDateAsDisplayValue();
    /**
     * @stable [08.03.2020]
     * @returns {ICalendarEntity}
     */
    private get currentCalendarEntity();
    /**
     * @stable [08.03.2020]
     * @returns {ICalendarEntity}
     */
    private get nextCalendarEntity();
    /**
     * @stable [08.03.2020]
     * @param {Date} date
     * @returns {ICalendarEntity}
     */
    private getCalendarEntity;
    /**
     * @stable [25.03.2020]
     * @returns {Date}
     */
    private get currentCalendarDate();
    /**
     * @stable [08.03.2020]
     * @returns {Date}
     */
    private get nextCalendarDate();
    /**
     * @stable [25.03.2020]
     * @returns {IFromToDayOfYearEntity}
     */
    private get currentFromToDayOfYearEntity();
    /**
     * @stable [07.03.2020]
     * @param {IDatesRangeEntity} entity
     * @returns {DatesRangeValueT}
     */
    private fromDatesRangeEntity;
    /**
     * @stable [07.03.2020]
     * @param {DatesRangeValueT} value
     * @returns {IDatesRangeEntity}
     */
    private fromDatesRangeValue;
    /**
     * @stable [07.03.2020]
     * @returns {IDatesRangeEntity}
     */
    private get datesRangeEntity();
    /**
     * @stable [06.03.2020]
     * @param {DateTimeLikeTypeT} date
     * @returns {Date}
     */
    private getValueAsDate;
    /**
     * @stable [10.03.2020]
     * @returns {IDatesRangeEntity}
     */
    private get acceptedDatesRangeEntity();
    /**
     * @stable [06.03.2020]
     * @returns {Date}
     */
    private get acceptedDateValue();
    /**
     * @stable [06.03.2020]
     * @returns {Date}
     */
    private get valueAsDate();
    /**
     * @stable [06.03.2020]
     * @returns {DatePeriodsEnum}
     */
    private get valueAsPeriodMode();
    /**
     * @stable [08.03.2020]
     * @returns {DatePeriodsEnum}
     */
    private get valueAsDateFrom();
    /**
     * @stable [09.03.2020]
     * @returns {DateTimeLikeTypeT}
     */
    private get valueAsDateTo();
    /**
     * @stable [06.03.2020]
     * @returns {DateFieldRangeValueT}
     */
    private get aheadValue();
    /**
     * @stable [07.03.2020]
     * @returns {IDatesRangeEntity}
     */
    private get aheadEntity();
    /**
     * @stable [07.03.2020]
     * @returns {DatePeriodsEnum}
     */
    private get aheadEntityPeriodMode();
    /**
     * @stable [07.03.2020]
     * @returns {DatePeriodsEnum}
     */
    private get selectedPeriodMode();
    /**
     * @stable [07.03.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isDaySelected;
    /**
     * @stable [08.03.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isRangeSelected;
    /**
     * @stable [07.03.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isFirstDaySelected;
    /**
     * @stable [07.03.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isLastDaySelected;
    /**
     * @stable [07.03.2020]
     * @param {ICalendarDayEntity} entity
     * @returns {boolean}
     */
    private isMiddleDaySelected;
    /**
     * @stable [07.03.2020]
     * @param {IFromToDayOfYearEntity} currentFromToDayOfYearEntity
     * @returns {boolean}
     */
    private isServiceDaySelected;
    /**
     * @stable [06.03.2020]
     * @returns {boolean}
     */
    private get isPreviousPeriodModeEnabled();
    /**
     * @stable [06.03.2020]
     * @returns {boolean}
     */
    private get isRangeEnabled();
    /**
     * @stable [21.08.2020]
     */
    private get isInline();
    /**
     * @stable [26.03.2020]
     * @returns {boolean}
     */
    private get isFieldMaskOrPatternApplicable();
    /**
     * @stable [25.03.2020]
     * @returns {boolean}
     */
    private get isPeriodNavigatorUsed();
    /**
     * stable [06.03.2020]
     * @returns {IDateTimeSettingsEntity}
     */
    private get dateTimeSettings();
    /**
     * @stable [26.03.2020]
     * @returns {string}
     */
    private get yearMonthFormat();
    /**
     * @stable [06.03.2020]
     * @returns {Dialog}
     */
    private get dialog();
}
