import * as React from 'react';
import { AnyT } from '../../../definitions.interface';
import { ChangeEventT, FieldComposedInputAttributesT, IBaseEvent, IField, IFieldProps, IFieldState, IFocusEvent, IKeyboardProps, IMaskedInputCtor, InputElementT } from '../../../definition';
import { DelayedTask } from '../../../util';
import { EnhancedGenericComponent } from '../../base/enhanced-generic.component';
export declare class Field<TProps extends IFieldProps, TState extends IFieldState> extends EnhancedGenericComponent<TProps, TState> implements IField<TProps, TState> {
    static readonly defaultProps: IFieldProps;
    protected readonly inputRef: React.RefObject<HTMLInputElement | HTMLTextAreaElement | IMaskedInputCtor>;
    protected caretBlinkingTask: DelayedTask;
    protected keyboardListenerUnsubscriber: () => void;
    protected readonly inputMirrorRef: React.RefObject<HTMLElement>;
    private readonly keyboardRef;
    /**
     * @stable [21.06.2020]
     * @param {TProps} originalProps
     */
    constructor(originalProps: TProps);
    /**
     * @stable [21.08.2020]
     */
    render(): JSX.Element;
    /**
     * @stable [21.06.2020]
     */
    componentDidMount(): void;
    /**
     * @stable [21.06.2020]
     */
    componentWillUnmount(): void;
    /**
     * @stable [21.06.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     */
    componentDidUpdate(prevProps: TProps, prevState: TState): void;
    /**
     * @stable [21.06.2020]
     * @param {ChangeEventT} event
     */
    onChange(event: ChangeEventT): void;
    /**
     * @stable [21.06.2020]
     * @param {TValue} currentRawValue
     */
    onChangeManually<TValue = AnyT>(currentRawValue: TValue): void;
    /**
     * @stable [10.09.2020]
     * @param event
     */
    onKeyEnter(event: IBaseEvent): void;
    /**
     * @stable [21.06.2020]
     */
    setFocus(): void;
    /**
     * @stable [21.06.2020]
     */
    clearValue(): void;
    /**
     * @stable [21.06.2020]
     * @param {ChangeEventT} event
     * @returns {AnyT}
     */
    getRawValueFromEvent(event: ChangeEventT): AnyT;
    /**
     * @stable [17.06.2020]
     * @returns {AnyT}
     */
    get value(): AnyT;
    /**
     * @stable [03.06.2020]
     * @returns {InputElementT}
     */
    get input(): InputElementT;
    /**
     * @stable [05.06.2020]
     */
    protected removeFocus(): void;
    /**
     * @stable [21.08.2020]
     */
    protected get displayValueElement(): React.ReactNode;
    /**
     * @stable [21.08.2020]
     */
    protected get waitMessageElement(): React.ReactNode;
    private get keyboardElement();
    /**
     * @stable [21.06.2020]
     * @param {IFocusEvent} event
     */
    protected onFocus(event: IFocusEvent): void;
    protected openVirtualKeyboard(): void;
    /**
     * @stable [17.06.2020]
     * @param {IBaseEvent} event
     */
    protected onClick(event: IBaseEvent): void;
    /**
     * @stable [03.06.2020]
     * @param {AnyT} currentRawValue
     */
    protected onChangeValue(currentRawValue: AnyT): void;
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @param {boolean} forceApplyValue
     * @returns {AnyT}
     */
    protected getDecoratedDisplayValue(value: AnyT, forceApplyValue?: boolean): AnyT;
    /**
     * @stable [17.06.2020]
     * @returns {AnyT}
     */
    protected get decoratedDisplayValue(): AnyT;
    /**
     * @stable [18.05.2020]
     * @param {AnyT} value
     * @returns {AnyT}
     */
    protected decorateDisplayValue(value: AnyT): AnyT;
    /**
     * @stable [18.05.2020]
     * @returns {FieldComposedInputAttributesT}
     */
    protected getInputElementProps(): FieldComposedInputAttributesT;
    /**
     * @stable [22.01.2020]
     * @returns {JSX.Element}
     */
    protected get actionsElement(): JSX.Element;
    /**
     * @stable [18.05.2020]
     * @returns {JSX.Element}
     */
    protected get inputWrapperElement(): JSX.Element;
    /**
     * @stable [18.05.2020]
     * @returns {JSX.Element}
     */
    protected getInputElement(): JSX.Element;
    /**
     * @stable [21.06.2020]
     * @returns {string}
     */
    protected getFieldClassName(): string;
    /**
     * @stable [21.08.2020]
     */
    protected getLabel(): string;
    /**
     * @stable [21.08.2020]
     */
    protected getFieldMask(): (string | RegExp)[];
    /**
     * @stable [21.08.2020]
     */
    protected getKeyboardProps(): IKeyboardProps;
    /**
     * @stable [21.08.2020]
     */
    protected getComponentsSettingsProps(): TProps;
    /**
     * @stable [21.08.2020]
     */
    protected get inputAttachmentElement(): JSX.Element;
    /**
     * @stable [21.08.2020]
     */
    protected get attachmentElement(): JSX.Element;
    /**
     * @stable [21.08.2020]
     */
    protected get mirrorInputElement(): JSX.Element;
    protected get isCursorUsed(): boolean;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    protected get isKeyboardAndCursorUsed(): boolean;
    /**
     * @stable [19.06.2020]
     * @returns {AnyT}
     */
    protected get emptyValue(): AnyT;
    /**
     * @stable [19.06.2020]
     * @returns {AnyT}
     */
    protected get originalEmptyValue(): AnyT;
    /**
     * @stable [19.06.2020]
     * @returns {AnyT}
     */
    protected get defaultValue(): AnyT;
    /**
     * @stable [19.06.2020]
     * @returns {AnyT}
     */
    protected get displayValue(): AnyT;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected isKeyboardOpen(): boolean;
    /**
     * @stable [19.06.2020]
     * @param {AnyT} value
     * @returns {boolean}
     */
    protected isValueObject(value: AnyT): boolean;
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    protected get isPlainValueApplied(): boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected get isValuePresent(): boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean | undefined}
     */
    protected get isKeyboardUsed(): boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected get isRequired(): boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected get isDisabled(): boolean;
    /**
     * @stable [20.06.2020]
     * @returns {boolean}
     */
    protected get isValueNotPresent(): boolean;
    /**
     * @stable [03.06.2020]
     * @param {AnyT} value
     * @returns {boolean}
     */
    protected isValueDefined(value: AnyT): boolean;
    /**
     * @stable [03.06.2020]
     * @returns {boolean}
     */
    protected get isInputValid(): boolean;
    /**
     * @stable [03.06.2020]
     * @returns {boolean}
     */
    protected get isFocusPrevented(): boolean;
    /**
     * @stable [05.06.2020]
     * @returns {boolean}
     */
    protected get isBusy(): boolean;
    /**
     * @stable [21.08.2020]
     */
    protected get isReadOnly(): boolean;
    /**
     * @stable [02.08.2020]
     */
    protected get isInactive(): boolean;
    /**
     * @stable [02.08.2020]
     */
    protected get isActive(): boolean;
    /**
     * @stable [22.06.2020]
     * @returns {boolean}
     */
    protected get isDisplayValueDefined(): boolean;
    /**
     * @stable [03.06.2020]
     * @returns {boolean}
     */
    protected get hasInput(): boolean;
    /**
     * @stable [03.06.2020]
     * @returns {TProps}
     */
    protected get componentsSettingsProps(): TProps;
    /**
     * @stable [21.06.2020]
     */
    private refreshCaretPosition;
    /**
     * @stable [21.06.2020]
     */
    private setCaretVisibility;
    /**
     * @stable [21.06.2020]
     * @param {AnyT} rawValue
     */
    private validateField;
    /**
     * @stable [21.06.2020]
     * @param {AnyT} value
     * @returns {string}
     */
    private validateValueAndSetCustomValidity;
    /**
     * @stable [21.06.2020]
     */
    private closeVirtualKeyboard;
    /**
     * @stable [21.06.2020]
     * @param {IBaseEvent} event
     */
    private onDocumentClickHandler;
    /**
     * @stable [21.06.2020]
     */
    private onCloseVirtualKeyboard;
    /**
     * @stable [21.06.2020]
     * @param {string} rawValue
     */
    private onKeyboardChange;
    /**
     * @stable [21.08.2020]
     * @param message
     * @param className
     */
    private messageElement;
    /**
     * @stable [21.08.2020]
     */
    private get selfElement();
    /**
     * @stable [21.08.2020]
     */
    private get labelElement();
    /**
     * @stable [21.08.2020]
     */
    private get prefixLabelElement();
    /**
     * @stable [21.06.2020]
     * @returns {JSX.Element}
     */
    private get inputCaretElement();
    /**
     * @stable [21.08.2020]
     */
    private get progressInfoElement();
    /**
     * @stable [21.08.2020]
     */
    private get title();
    /**
     * @stable [21.06.2020]
     * @returns {number}
     */
    private get caretPosition();
    /**
     * @stable [21.08.2020]
     */
    private get isErrorMessageRendered();
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    private get areManualChangesNotPrevented();
    /**
     * @stable [21.06.2020]
     * @returns {boolean}
     */
    private get isInvalid();
    /**
     * @stable [21.08.2020]
     */
    private get isFocused();
    /**
     * @stable [21.08.2020]
     */
    private get isInlineKeyboard();
    /**
     * @stable [21.08.2020]
     */
    private get inputValidationMessage();
    /**
     * @stable [21.08.2020]
     */
    private get error();
    /**
     * @stable [21.08.2020]
     */
    private get isChangeable();
    /**
     * @stable [21.08.2020]
     */
    private get isFieldRendered();
}
