"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.Viewer = void 0;
var React = require("react");
var R = require("ramda");
var util_1 = require("../../util");
var definition_1 = require("../../definition");
var definitions_interface_1 = require("../../definitions.interface");
var button_component_1 = require("../button/button.component");
var dialog_component_1 = require("../dialog/dialog.component");
var generic_component_1 = require("../base/generic.component");
var info_component_1 = require("../info/info.component");
var Viewer = /** @class */ (function (_super) {
    __extends(Viewer, _super);
    /**
     * @stable [16.03.2020]
     * @param {TProps} props
     */
    function Viewer(props) {
        var _this = _super.call(this, props) || this;
        _this.previewDialogRef = React.createRef();
        _this.onBack = _this.onBack.bind(_this);
        _this.onDecrementScale = _this.onDecrementScale.bind(_this);
        _this.onDialogClose = _this.onDialogClose.bind(_this);
        _this.onForward = _this.onForward.bind(_this);
        _this.onIncrementScale = _this.onIncrementScale.bind(_this);
        _this.onLoadError = _this.onLoadError.bind(_this);
        _this.onLoadStart = _this.onLoadStart.bind(_this);
        _this.onLoadSucceed = _this.onLoadSucceed.bind(_this);
        _this.showPreviewDialog = _this.showPreviewDialog.bind(_this);
        _this.state = {};
        return _this;
    }
    /**
     * @stable [16.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     */
    Viewer.prototype.componentDidUpdate = function (prevProps, prevState) {
        if (this.hasSrcChanges(prevProps, prevState)) {
            this.refreshOnSrcChanges();
        }
        else if (this.hasInternalChanges(prevProps, prevState)) {
            this.refreshOnInternalChanges();
        }
    };
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.componentDidMount = function () {
        this.refreshOnSrcChanges();
    };
    /**
     * @stable [02.10.2020]
     */
    Viewer.prototype.render = function () {
        var style = this.originalProps.style;
        return (React.createElement("div", { style: style, className: this.getClassName() },
            this.originalChildren,
            this.bodyElement,
            this.previewIconElement,
            this.previewDialogElement));
    };
    /**
     * @stable [16.03.2020]
     * @returns {JSX.Element}
     */
    Viewer.prototype.getPreviewExtraActionsElement = function () {
        return (React.createElement(React.Fragment, null,
            this.incrementScaleAction,
            this.decrementScaleAction,
            this.previewBackActionElement,
            this.previewForwardActionElement));
    };
    Object.defineProperty(Viewer.prototype, "previewForwardActionElement", {
        /**
         * @stable [18.03.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(button_component_1.Button, { icon: definition_1.IconsEnum.ARROW_RIGHT, disabled: this.isPreviewForwardActionDisabled(), onClick: this.onForward }));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "previewBackActionElement", {
        /**
         * @stable [18.03.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(button_component_1.Button, { icon: definition_1.IconsEnum.ARROW_LEFT, disabled: this.isPreviewBackActionDisabled(), onClick: this.onBack }));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "incrementScaleAction", {
        /**
         * @stable [18.03.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(button_component_1.Button, { icon: definition_1.IconsEnum.SEARCH_PLUS, onClick: this.onIncrementScale }));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "decrementScaleAction", {
        /**
         * @stable [18.03.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (React.createElement(button_component_1.Button, { icon: definition_1.IconsEnum.SEARCH_MINUS, onClick: this.onDecrementScale }));
        },
        enumerable: false,
        configurable: true
    });
    /**
     * @stable [18.03.2020]
     * @param {AnyT} error
     */
    Viewer.prototype.onLoadError = function (error) {
        this.setState({ error: error, progress: false });
    };
    /**
     * @stable [18.03.2020]
     * @param {(...args) => void} callback
     */
    Viewer.prototype.onLoadSucceed = function (callback) {
        this.setState({ progress: false }, callback);
    };
    /**
     * @stable [18.03.2020]
     */
    Viewer.prototype.onLoadStart = function () {
        this.setState({ error: null, progress: true });
    };
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    Viewer.prototype.isPreviewForwardActionDisabled = function () {
        return false;
    };
    /**
     * @stable [16.03.2020]
     * @returns {boolean}
     */
    Viewer.prototype.isPreviewBackActionDisabled = function () {
        var previewPage = this.state.previewPage;
        return !previewPage || previewPage === Viewer.DEFAULT_PAGE;
    };
    /**
     * @stable [19.06.2020]
     * @returns {string}
     */
    Viewer.prototype.getClassName = function () {
        var originalProps = this.originalProps;
        var className = this.originalProps.className;
        return util_1.ClsUtils.joinClassName(definition_1.ViewerClassesEnum.VIEWER, this.isSrcAbsent && definition_1.ViewerClassesEnum.EMPTY_VIEWER, this.isInfoRendered && definition_1.ViewerClassesEnum.INFO_VIEWER, util_1.WrapperUtils.isFull(originalProps) && definition_1.ViewerClassesEnum.FULL_VIEWER, util_1.CalcUtils.calc(className));
    };
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.refreshOnSrcChanges = function () {
        // Do nothing
    };
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.refreshOnInternalChanges = function () {
        // Do nothing
    };
    Object.defineProperty(Viewer.prototype, "inProgress", {
        /**
         * @stable [02.08.2020]
         */
        get: function () {
            return util_1.WrapperUtils.inProgress(this.state);
        },
        enumerable: false,
        configurable: true
    });
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.onDialogClose = function () {
        this.setState({
            opened: false,
            previewPage: definitions_interface_1.UNDEF,
            previewScale: definitions_interface_1.UNDEF,
        });
    };
    /**
     * @stable [16.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     * @returns {boolean}
     */
    Viewer.prototype.hasInternalChanges = function (prevProps, prevState) {
        return (this.hasPageChanges(prevProps, prevState)
            || this.hasScaleChanges(prevProps, prevState));
    };
    /**
     * @stable [15.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     * @returns {boolean}
     */
    Viewer.prototype.hasScaleChanges = function (prevProps, prevState) {
        return util_1.ObjectUtils.isCurrentValueNotEqualPreviousValue(this.props.scale, prevProps.scale);
    };
    /**
     * @stable [16.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     * @returns {boolean}
     */
    Viewer.prototype.hasSrcChanges = function (prevProps, prevState) {
        return util_1.ObjectUtils.isCurrentValueNotEqualPreviousValue(this.props.src, prevProps.src);
    };
    /**
     * @stable [16.03.2020]
     * @param {TProps} prevProps
     * @param {TState} prevState
     * @returns {boolean}
     */
    Viewer.prototype.hasPageChanges = function (prevProps, prevState) {
        return (util_1.ObjectUtils.isCurrentValueNotEqualPreviousValue(this.props.page, prevProps.page)
            || util_1.ObjectUtils.isCurrentValueNotEqualPreviousValue(this.state.page, prevState.page));
    };
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.onBack = function () {
        this.setState({ previewPage: this.actualOrDefaultPreviewPage - 1 });
    };
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.onForward = function () {
        this.setState({ previewPage: this.actualOrDefaultPreviewPage + 1 });
    };
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.onIncrementScale = function () {
        this.setState({ previewScale: this.actualOrDefaultPreviewScale + this.defaultScaleDiff });
    };
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.onDecrementScale = function () {
        this.setState({ previewScale: this.actualOrDefaultPreviewScale - this.defaultScaleDiff });
    };
    /**
     * @stable [16.03.2020]
     */
    Viewer.prototype.showPreviewDialog = function () {
        var _this = this;
        this.setState({ opened: true }, function () { return _this.previewDialogRef.current.activate(); });
    };
    Object.defineProperty(Viewer.prototype, "actualOrDefaultPage", {
        /**
         * @stable [16.03.2020]
         * @returns {number}
         */
        get: function () {
            return util_1.NvlUtils.nvl(this.actualPage, Viewer.DEFAULT_PAGE);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "actualPage", {
        /**
         * @stable [02.10.2020]
         */
        get: function () {
            return util_1.NvlUtils.nvl(this.state.page, this.originalProps.page);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "actualOrDefaultPreviewPage", {
        /**
         * @stable [16.03.2020]
         * @returns {number}
         */
        get: function () {
            return util_1.NvlUtils.nvl(this.actualPreviewPage, Viewer.DEFAULT_PAGE);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "actualPreviewPage", {
        /**
         * @stable [16.03.2020]
         * @returns {number}
         */
        get: function () {
            return util_1.NvlUtils.nvl(this.state.previewPage, this.props.previewPage);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "actualOrDefaultPreviewScale", {
        /**
         * @stable [02.10.2020]
         */
        get: function () {
            return util_1.NvlUtils.coalesce(this.state.previewScale, this.originalProps.previewScale, this.defaultScale);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "actualOrDefaultScale", {
        /**
         * @stable [02.10.2020]
         */
        get: function () {
            return util_1.NvlUtils.coalesce(this.state.scale, this.originalProps.scale, this.defaultScale);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "actualSrc", {
        /**
         * @stable [18.03.2020]
         * @returns {string}
         */
        get: function () {
            return this.props.src || this.props.defaultScr;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "defaultScaleDiff", {
        /**
         * @stable [23.03.2020]
         * @returns {number}
         */
        get: function () {
            return .3;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "defaultScale", {
        /**
         * @stable [23.03.2020]
         * @returns {number}
         */
        get: function () {
            return 1;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "bodyElement", {
        /**
         * @stable [19.06.2020]
         * @returns {React.ReactNode}
         */
        get: function () {
            var AN_ERROR_OCCURRED_DURING_LOADING_THE_FILE = this.settings.messages.AN_ERROR_OCCURRED_DURING_LOADING_THE_FILE;
            var Component = this.viewerLocator.resolve(definition_1.ViewersEnum.PICTURE);
            return this.isInfoRendered
                ? (React.createElement(info_component_1.Info, { progress: this.inProgress, error: AN_ERROR_OCCURRED_DURING_LOADING_THE_FILE }))
                : (this.isActualSrcAbsent
                    ? React.createElement(Component, null)
                    : this.getContentElement());
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "previewDialogElement", {
        /**
         * @stable [16.03.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            var messages = this.settings.messages;
            var state = this.state;
            return util_1.isOpened(state) && this.canPreview && (React.createElement(dialog_component_1.Dialog, { ref: this.previewDialogRef, className: definition_1.DialogClassesEnum.PREVIEW_DIALOG, title: messages.PREVIEW, closeText: messages.CLOSE, acceptable: false, extraActions: this.getPreviewExtraActionsElement(), onDeactivate: this.onDialogClose }, this.gePreviewElement()));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "previewIconElement", {
        /**
         * @stable [18.03.2020]
         * @returns {JSX.Element}
         */
        get: function () {
            return (this.canPreview && (this.uiFactory.makeIcon({
                type: definition_1.IconsEnum.SEARCH_PLUS,
                className: util_1.ClsUtils.joinClassName(definition_1.ComponentClassesEnum.ALIGNMENT_CENTER, definition_1.ViewerClassesEnum.VIEWER_PREVIEW_ICON),
                onClick: this.showPreviewDialog,
            })));
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "isInfoRendered", {
        /**
         * @stable [18.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.inProgress || this.doesErrorExist;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "canPreview", {
        /**
         * @stable [16.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.isPreviewUsed
                && !this.inProgress
                && !this.isActualSrcAbsent
                && !this.doesErrorExist;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "doesErrorExist", {
        /**
         * @stable [16.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return !R.isNil(this.state.error);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "isActualSrcAbsent", {
        /**
         * @stable [16.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return this.isSrcAbsent && this.isDefaultSrcAbsent;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "isSrcAbsent", {
        /**
         * @stable [16.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return R.isNil(this.props.src);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "isDefaultSrcAbsent", {
        /**
         * @stable [16.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return R.isNil(this.props.defaultScr);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(Viewer.prototype, "isPreviewUsed", {
        /**
         * @stable [16.03.2020]
         * @returns {boolean}
         */
        get: function () {
            return util_1.isPreviewUsed(this.props);
        },
        enumerable: false,
        configurable: true
    });
    Viewer.DEFAULT_PAGE = 1;
    return Viewer;
}(generic_component_1.GenericComponent));
exports.Viewer = Viewer;
//# sourceMappingURL=viewer.component.js.map