"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LoadedListMiddlewareFactories = exports.makeLoadedListOnNavigateToLastPageMiddleware = exports.makeLoadedListOnNavigateToFirstPageMiddleware = exports.makeLoadedListOnNavigateToNextPageMiddleware = exports.makeLoadedListOnNavigateToPreviousPageMiddleware = exports.makeLoadedListOnToolbarToolsRefreshMiddleware = exports.makeLoadedListOnFormValidMiddleware = void 0;
var action_builder_1 = require("../../component/action.builder");
var util_1 = require("../../util");
var default_form_changes_middleware_1 = require("./default-form-changes.middleware");
/**
 * @stable [09.09.2020]
 * @param cfg
 */
var makeLoadedListMiddleware = function (cfg) {
    return action_builder_1.ListActionBuilder.buildLoadAction(util_1.SectionUtils.asListSection(cfg));
};
/**
 * @stable [09.09.2020]
 * @param config
 */
exports.makeLoadedListOnFormValidMiddleware = function (config) {
    return util_1.ConditionUtils.orNull(util_1.ValueUtils.isValueValid(util_1.selectValidFromAction(config.action)), function () { return makeLoadedListMiddleware(config); });
};
/**
 * @stable [22.09.2020]
 * @param config
 */
var makeLoadedListOnTabActivateMiddleware = function (config) {
    return makeLoadedListMiddleware(config);
};
/**
 * @stable [09.09.2020]
 * @param config
 */
exports.makeLoadedListOnToolbarToolsRefreshMiddleware = function (config) {
    return makeLoadedListMiddleware(config);
};
/**
 * @stable [20.09.2020]
 * @param cfg
 */
var makeUntouchedListMiddleware = function (cfg) {
    return util_1.ConditionUtils.ifNotEmptyThanValue(util_1.FilterUtils.notNilValuesArrayFilter(default_form_changes_middleware_1.DefaultFormChangesMiddlewareFactories.defaultFormChangesMiddleware(cfg), util_1.ConditionUtils.orNull(!util_1.WrapperUtils.isTouched(cfg.listAccessor(cfg.state)), function () { return makeLoadedListMiddleware(cfg); })), function (actions) { return actions; });
};
/**
 * @stable [09.09.2020]
 * @param cfg
 */
exports.makeLoadedListOnNavigateToPreviousPageMiddleware = function (cfg) {
    return [
        action_builder_1.ListActionBuilder.buildPreviousPageAction(util_1.SectionUtils.asListSection(cfg)),
        makeLoadedListMiddleware(cfg)
    ];
};
/**
 * @stable [09.09.2020]
 * @param cfg
 */
exports.makeLoadedListOnNavigateToNextPageMiddleware = function (cfg) {
    return [
        action_builder_1.ListActionBuilder.buildNextPageAction(util_1.SectionUtils.asListSection(cfg)),
        makeLoadedListMiddleware(cfg)
    ];
};
/**
 * @stable [09.09.2020]
 * @param cfg
 */
exports.makeLoadedListOnNavigateToFirstPageMiddleware = function (cfg) {
    return [
        action_builder_1.ListActionBuilder.buildFirstPageAction(util_1.SectionUtils.asListSection(cfg)),
        makeLoadedListMiddleware(cfg)
    ];
};
/**
 * @stable [09.09.2020]
 * @param cfg
 */
exports.makeLoadedListOnNavigateToLastPageMiddleware = function (cfg) {
    return [
        action_builder_1.ListActionBuilder.buildLastPageAction(util_1.SectionUtils.asListSection(cfg)),
        makeLoadedListMiddleware(cfg)
    ];
};
/**
 * @stable [09.09.2020]
 */
var LoadedListMiddlewareFactories = /** @class */ (function () {
    function LoadedListMiddlewareFactories() {
    }
    LoadedListMiddlewareFactories.loadedListMiddleware = makeLoadedListMiddleware;
    LoadedListMiddlewareFactories.loadedListOnTabActivateMiddleware = makeLoadedListOnTabActivateMiddleware;
    LoadedListMiddlewareFactories.untouchedListMiddleware = makeUntouchedListMiddleware;
    return LoadedListMiddlewareFactories;
}());
exports.LoadedListMiddlewareFactories = LoadedListMiddlewareFactories;
//# sourceMappingURL=loaded-list.middleware.js.map