import { CronPeriodsEnum, ICronEntity, ICronPlainEntity } from '../definition';
/**
 * @stable [15.11.2019]
 *
 *  * * * * * * *
 *  | | | | | |
 *  | | | | | +-- Year              (range: 1900-3000)
 *  | | | | +---- Day of the Week   (range: 0-6 (Sunday to Saturday))
 *  | | | +------ Month of the Year (range: 1-12)
 *  | | +-------- Day of the Month  (range: 1-31)
 *  | +---------- Hour              (range: 0-23)
 *  +------------ Minute            (range: 0-59)
 *
 *  Last days:
 *  Also, one other character is sometimes available to the DoM and DoW parameters: L. It is used differently for each
 *  parameter, however.
 *  - For DoM, a lone “L” means the last day of the month.
 *  - For DoW, the “L” is added to the day number to indicate the last day of the month. For example, “1L” would indicate
 *    the last Monday of the month.
 *
 * @param {string} expression
 * @param {Date} from
 * @param {Date} to
 * @returns {ICronEntity}
 */
export declare const fromCronExpression: (expression?: string, from?: Date, to?: Date) => ICronPlainEntity;
/**
 * @stable [14.12.2019]
 */
export declare class CronEntity implements ICronEntity {
    static newInstance(): CronEntity;
    daysOfMonths: number[];
    daysOfWeeks: number[];
    hours: number[];
    minutes: number[];
    months: number[];
    years: number[];
    allDaysOfMonth: boolean;
    allDaysOfWeek: boolean;
    allHours: boolean;
    allMinutes: boolean;
    allMonths: boolean;
    allYears: boolean;
    private expression;
    private from;
    private to;
    /**
     * @stable [15.12.2019]
     * @param {Date} to
     * @returns {CronEntity}
     */
    withDateTo(to: Date): CronEntity;
    /**
     * @stable [15.12.2019]
     * @param {Date} from
     * @returns {CronEntity}
     */
    withDateFrom(from: Date): CronEntity;
    /**
     * @stable [15.12.2019]
     * @param {string} expression
     * @returns {CronEntity}
     */
    fromExpression(expression?: string): ICronEntity;
    /**
     * @stable [15.12.2019]
     * @param {boolean} returnNeverExecutablePeriodAsEmptyValue
     * @returns {string}
     */
    toExpression(returnNeverExecutablePeriodAsEmptyValue?: boolean): string;
    /**
     * @stable [14.12.2019]
     * @returns {ICronPlainEntity}
     */
    asPlainObject(): ICronPlainEntity;
    /**
     * @stable [19.12.2019]
     * @returns {CronPeriodsEnum}
     */
    asPeriodType(): CronPeriodsEnum;
    /**
     * @stable [14.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    withMonths(...values: number[]): CronEntity;
    /**
     * @stable [14.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    withYears(...values: number[]): CronEntity;
    /**
     * @stable [14.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    withMinutes(...values: number[]): CronEntity;
    /**
     * @stable [14.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    withHours(...values: number[]): CronEntity;
    /**
     * @stable [14.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    withDaysOfWeeks(...values: number[]): CronEntity;
    /**
     * @stable [14.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    withLastDaysOfWeeks(...values: number[]): CronEntity;
    /**
     * @stable [14.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    withDaysOfMonths(...values: number[]): CronEntity;
    /**
     * @stable [14.12.2019]
     * @param {number[]} extraValues
     * @returns {CronEntity}
     */
    withLastDayOfMonth(...extraValues: number[]): CronEntity;
    /**
     * @stable [15.12.2019]
     * @param {number} value
     * @returns {boolean}
     */
    hasDayOfMonth(value: number): boolean;
    /**
     * @stable [15.12.2019]
     * @param {number} value
     * @returns {boolean}
     */
    hasDayOfWeek(value: number): boolean;
    /**
     * @stable [15.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    addDaysOfMonths(...values: number[]): CronEntity;
    /**
     * @stable [15.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    addDaysOfWeeks(...values: number[]): CronEntity;
    /**
     * @stable [15.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    excludeDaysOfMonths(...values: number[]): CronEntity;
    /**
     * @stable [15.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    excludeDaysOfWeeks(...values: number[]): CronEntity;
    /**
     * @stable [15.12.2019]
     * @param {number[]} values
     * @param {number[]} excludedValues
     * @returns {number[]}
     */
    private excludeValues;
    /**
     * @stable [14.12.2019]
     * @param {number} values
     * @returns {CronEntity}
     */
    private normalize;
    /**
     * @stable [14.12.2019]
     */
    private refreshAllDaysOfWeek;
    /**
     * @stable [14.12.2019]
     */
    private refreshAllDaysOfMonth;
    /**
     * @stable [14.12.2019]
     */
    private refreshAllHours;
    /**
     * @stable [14.12.2019]
     */
    private refreshAllMinutes;
    /**
     * @stable [14.12.2019]
     */
    private refreshAllYears;
    /**
     * @stable [14.12.2019]
     */
    private refreshAllMonths;
}
