import { AnyT, EntityIdT, IEntity, IKeyValue } from '../definitions.interface';
import { IGenericFieldEntity, IGenericFieldEntity2, IMultiItemEntity, MultiFieldValueOrEntityIdT, MultiFieldValueT } from '../definition';
/**
 * @stable [27.08.2019]
 * @param {EntityIdT} key
 * @returns {string}
 */
export declare const dynamicFieldName: (key: EntityIdT) => string;
/**
 * @stable [28.08.2019]
 * @param {TEntity[]} array
 * @param {(itm: TEntity) => EntityIdT} keyAccessor
 * @param {(itm: TEntity) => EntityIdT} valueAccessor
 * @returns {IKeyValue}
 */
export declare const fromDynamicFieldsArray: <TEntity extends string | number | IEntity>(array: TEntity[], keyAccessor: (itm: TEntity) => EntityIdT, valueAccessor: (itm: TEntity) => EntityIdT) => IKeyValue;
/**
 * @stable [14.02.2020]
 * @param {EntityIdT[]} array
 * @param {(itm: EntityIdT) => AnyT} valueAccessor
 * @returns {IKeyValue}
 */
export declare const fromDynamicFieldsIdsArray: (array: EntityIdT[], valueAccessor: (itm: EntityIdT) => AnyT) => IKeyValue;
/**
 * @stable [22.11.2019]
 * @param {MultiFieldValueT} entity
 * @returns {TEntity[]}
 */
export declare const asMultiFieldAddedEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldValueT<TEntity>) => TEntity[];
/**
 * @stable [14.10.2019]
 * @param {MultiFieldValueOrEntityIdT} value
 * @returns {number}
 */
export declare const asMultiFieldEntitiesLength: (value: MultiFieldValueOrEntityIdT) => number;
/**
 * @stable [14.10.2019]
 * @param {MultiFieldValueT<TEntity extends IEntity>} value
 * @param {number} entitiesCountLimit
 * @returns {TEntity[]}
 */
export declare const asOrderedMultiFieldEntities: <TEntity extends IEntity = IEntity>(value: MultiFieldValueT<TEntity>, entitiesCountLimit: number) => TEntity[];
export declare const buildMultiItemEntity: <TEntity extends IEntity = IEntity>(name: string, value: AnyT, rawData: TEntity, newEntity?: boolean) => IMultiItemEntity;
/**
 * @stable [19.11.2019]
 * @param {TEntity} original
 * @param {MultiFieldValueT<TEntity extends IEntity>} multiFieldEntity
 * @returns {{id: number}}
 */
export declare const buildNewPhantomMultiItem: <TEntity extends IEntity = IEntity>(original: TEntity, multiFieldEntity: MultiFieldValueT<TEntity>) => TEntity;
/**
 * @stable [16.05.2020]
 */
export declare class FieldUtils {
    static readonly asActualFieldValue: (config: IGenericFieldEntity2) => any;
    static readonly dynamicFieldName: (key: import("../definitions.interface").StringNumberT) => string;
    static readonly dynamicFieldValue: <TEntity = IEntity>(object: TEntity, key: import("../definitions.interface").StringNumberT) => any;
    static readonly fromMultiFieldValueToDefinedEntities: <TEntity extends IEntity = IEntity>(entity: MultiFieldValueT<TEntity>) => TEntity[];
    static readonly isFieldInactive: (entity: IGenericFieldEntity) => boolean;
}
