"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.FieldUtils = exports.buildNewPhantomMultiItem = exports.buildMultiItemEntity = exports.asOrderedMultiFieldEntities = exports.asMultiFieldEntitiesLength = exports.asMultiFieldAddedEntities = exports.fromDynamicFieldsIdsArray = exports.fromDynamicFieldsArray = exports.dynamicFieldName = void 0;
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var definition_1 = require("../definition");
var cond_1 = require("./cond");
var array_1 = require("./array");
var type_1 = require("./type");
var wrapper_1 = require("./wrapper");
var filter_1 = require("./filter");
var multi_field_1 = require("./multi-field");
/**
 * @stable [18.05.2020]
 * @param {IGenericFieldEntity2} config
 * @returns {AnyT}
 */
var asActualFieldValue = function (config) {
    var emptyValue = config.emptyValue, keepChanges = config.keepChanges, originalValue = config.originalValue, value = config.value;
    var isOriginalValueDefined = type_1.TypeUtils.isDef(originalValue);
    var originalOrEmptyValue = isOriginalValueDefined ? originalValue : emptyValue;
    return type_1.TypeUtils.isDef(originalOrEmptyValue) && R.equals(value, originalOrEmptyValue)
        ? (isOriginalValueDefined
            ? definition_1.FieldConstants.VALUE_TO_CLEAR_DIRTY_CHANGES
            : (keepChanges ? value : definition_1.FieldConstants.VALUE_TO_CLEAR_DIRTY_CHANGES))
        : value;
};
/**
 * @stable [02.08.2020]
 * @param entity
 */
var isFieldInactive = function (entity) {
    return wrapper_1.isDisabled(entity) || wrapper_1.WrapperUtils.isReadOnly(entity) || wrapper_1.WrapperUtils.inProgress(entity);
};
/**
 * @stable [27.08.2019]
 * @param {EntityIdT} key
 * @returns {string}
 */
exports.dynamicFieldName = function (key) { return "$$dynamicField-" + key; };
/**
 * @stable [29.06.2020]
 * @param object
 * @param key
 */
var dynamicFieldValue = function (object, key) { return object[exports.dynamicFieldName(key)]; };
/**
 * @stable [28.08.2019]
 * @param {TEntity[]} array
 * @param {(itm: TEntity) => EntityIdT} keyAccessor
 * @param {(itm: TEntity) => EntityIdT} valueAccessor
 * @returns {IKeyValue}
 */
exports.fromDynamicFieldsArray = function (array, keyAccessor, valueAccessor) {
    return R.mergeAll(array.map(function (itm) {
        var _a;
        return (_a = {},
            _a[exports.dynamicFieldName(keyAccessor(itm))] = valueAccessor(itm),
            _a);
    }));
};
/**
 * @stable [14.02.2020]
 * @param {EntityIdT[]} array
 * @param {(itm: EntityIdT) => AnyT} valueAccessor
 * @returns {IKeyValue}
 */
exports.fromDynamicFieldsIdsArray = function (array, valueAccessor) {
    return exports.fromDynamicFieldsArray(array, function (itm) { return itm; }, valueAccessor);
};
/**
 * @stable [29.08.2020]
 * @param entity
 */
var fromMultiFieldValueToDefinedEntities = function (entity) {
    return multi_field_1.MultiFieldUtils.multiFieldValueAsEntities(entity) || [];
};
/**
 * @stable [22.11.2019]
 * @param {MultiFieldValueT} entity
 * @returns {TEntity[]}
 */
exports.asMultiFieldAddedEntities = function (entity) {
    if (R.isNil(entity)) {
        return definitions_interface_1.UNDEF;
    }
    if (multi_field_1.MultiFieldUtils.isNotMultiEntity(entity)) {
        return [];
    }
    var multiEntity = entity;
    return multiEntity.add;
};
/**
 * @stable [14.10.2019]
 * @param {MultiFieldValueOrEntityIdT} value
 * @returns {number}
 */
exports.asMultiFieldEntitiesLength = function (value) { return cond_1.ifNotNilThanValue(value, function () { return (multi_field_1.MultiFieldUtils.isNotMultiEntity(value)
    ? multi_field_1.MultiFieldUtils.notMultiFieldValueAsEntities(value)
    : multi_field_1.MultiFieldUtils.multiFieldValueAsEntities(value)).length; }, 0); };
/**
 * @stable [14.10.2019]
 * @param {MultiFieldValueT<TEntity extends IEntity>} value
 * @param {number} entitiesCountLimit
 * @returns {TEntity[]}
 */
exports.asOrderedMultiFieldEntities = function (value, entitiesCountLimit) {
    var result = array_1.makeArray(entitiesCountLimit);
    var multiFieldEntities = multi_field_1.MultiFieldUtils.multiFieldValueAsEntities(value);
    if (Array.isArray(multiFieldEntities)) {
        var cursor_1 = 0;
        result.forEach(function (_, index) {
            var entity = multiFieldEntities[index];
            if (!R.isNil(entity)) {
                if (entity.newEntity) {
                    result[entity.index] = entity;
                }
                else {
                    result[cursor_1++] = entity;
                }
            }
        });
    }
    return result;
};
// TODO Deprecated
exports.buildMultiItemEntity = function (name, value, rawData, newEntity) {
    return filter_1.defValuesFilter({ id: rawData.id, value: value, name: name, rawData: rawData, newEntity: newEntity });
};
/**
 * @stable [19.11.2019]
 * @param {TEntity} original
 * @param {MultiFieldValueT<TEntity extends IEntity>} multiFieldEntity
 * @returns {{id: number}}
 */
exports.buildNewPhantomMultiItem = function (original, multiFieldEntity) { return (__assign(__assign({}, original), { id: array_1.arrayNextMinNegativeValue(multi_field_1.MultiFieldUtils.multiFieldValueAsEntitiesIds(multiFieldEntity) || []) })); };
/**
 * @stable [16.05.2020]
 */
var FieldUtils = /** @class */ (function () {
    function FieldUtils() {
    }
    FieldUtils.asActualFieldValue = asActualFieldValue; /* @stable [16.05.2020] */
    FieldUtils.dynamicFieldName = exports.dynamicFieldName; /* @stable [29.06.2020] */
    FieldUtils.dynamicFieldValue = dynamicFieldValue; /* @stable [29.06.2020] */
    FieldUtils.fromMultiFieldValueToDefinedEntities = fromMultiFieldValueToDefinedEntities; /* @stable [16.05.2020] */
    FieldUtils.isFieldInactive = isFieldInactive; /* @stable [02.08.2020] */
    return FieldUtils;
}());
exports.FieldUtils = FieldUtils;
//# sourceMappingURL=field.js.map