"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PageUtils = void 0;
var util_1 = require("../util");
var definition_1 = require("../definition");
/**
 * @stable [05.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @returns {number}
 */
var pageCursorFrom = function (entity) { return 1 + (entity.page - definition_1.FIRST_PAGE) * entity.pageSize; };
/**
 * @stable [05.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @returns {number}
 */
var pageCursorTo = function (entity) {
    return util_1.ConditionUtils.ifNotNilThanValue(entity.pageSize, function (pageSize) { return Math.min(entity.page * pageSize, entity.totalCount); });
};
/**
 * @stable [05.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @returns {number}
 */
var pagesCount = function (entity) { return Math.ceil(entity.totalCount / entity.pageSize); };
/**
 * @stable [05.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @returns {boolean}
 */
var isPageCursorInEndPosition = function (entity) {
    return pageCursorTo(entity) === entity.totalCount;
};
/**
 * @stable [05.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @returns {boolean}
 */
var isPageCursorInStartPosition = function (entity) {
    return entity.page === definition_1.FIRST_PAGE;
};
/**
 * @stable [05.05.2020]
 * @param {IReduxPaginatedEntity} entity
 * @returns {boolean}
 */
var isPageable = function (entity) { return entity.totalCount > entity.pageSize; };
/**
 * @stable [10.06.2020]
 */
var PageUtils = /** @class */ (function () {
    function PageUtils() {
    }
    PageUtils.isPageable = isPageable;
    PageUtils.isPageCursorInEndPosition = isPageCursorInEndPosition;
    PageUtils.isPageCursorInStartPosition = isPageCursorInStartPosition;
    PageUtils.pageCursorFrom = pageCursorFrom;
    PageUtils.pageCursorTo = pageCursorTo;
    PageUtils.pagesCount = pagesCount;
    return PageUtils;
}());
exports.PageUtils = PageUtils;
//# sourceMappingURL=page.js.map