"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Selectors = exports.selectSelectedEntityIdFromAction = exports.selectSelectedEntityFromAction = exports.selectValidFromAction = exports.selectValid = exports.selectData = exports.selectEntity = exports.selectChanges = exports.selectToken = void 0;
var R = require("ramda");
var definitions_interface_1 = require("../definitions.interface");
var nvl_1 = require("./nvl");
var definition_1 = require("../definition");
var cond_1 = require("./cond");
var wrapper_1 = require("./wrapper");
/**
 * @stable [30.03.2020]
 * @param {IQueueWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectQueue = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.queue;
};
/**
 * @stable [30.03.2020]
 * @param {IRawDataWrapper<TData>} wrapper
 * @returns {TData}
 */
var selectRawData = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.rawData;
};
/**
 * @stable [06.04.2020]
 * @param {IElementWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectElement = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.element;
};
/**
 * @stable [31.07.2020]
 * @param entity
 */
var selectEntityId = function (entity) { return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.id; };
/**
 * @stable [22.09.2020]
 * @param wrapper
 */
var selectForm = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.form;
};
/**
 * @stable [22.09.2020]
 * @param wrapper
 */
var selectSecondaryFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.secondaryFilter;
};
/**
 * @stable [22.09.2020]
 * @param wrapper
 */
var selectPrimaryFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.primaryFilter;
};
/**
 * @stable [22.09.2020]
 * @param wrapper
 */
var selectList = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.list;
};
/**
 * @stable [22.09.2020]
 * @param entity
 */
var selectError = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.error;
};
/**
 * @stable [22.09.2020]
 * @param wrapper
 */
var selectFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.filter;
};
/**
 * @stable [01.08.2020]
 * @param wrapper
 */
var selectQueryFilter = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.queryFilter;
};
/**
 * @stable [29.02.2020]
 * @param {ITokenWrapper<TValue>} wrapper
 * @returns {TValue}
 */
exports.selectToken = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.token;
};
/**
 * @stable [05.03.2020]
 * @param {IChangesWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectChanges = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.changes;
};
/**
 * @stable [05.03.2020]
 * @param {IEntityWrapper<TResult>} entity
 * @returns {TResult}
 */
exports.selectEntity = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.entity;
};
/**
 * @stable [05.03.2020]
 * @param {IDataWrapper<TData>} wrapper
 * @returns {TData}
 */
exports.selectData = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.data;
};
/**
 * @stable [30.07.2020]
 * @param wrapper
 */
var selectActiveValue = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.activeValue;
};
/**
 * @stable [26.07.2020]
 * @param wrapper
 */
var selectPayload = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.payload;
};
/**
 * @stable [26.07.2020]
 * @param action
 */
var selectPayloadFromAction = function (action) {
    return selectPayload(exports.selectData(action));
};
/**
 * @stable [27.03.2020]
 * @param {IValidWrapper} wrapper
 * @returns {boolean}
 */
exports.selectValid = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.valid;
};
/**
 * @stable [27.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
exports.selectValidFromAction = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : exports.selectValid(wrapper.data);
};
/**
 * @stable [26.03.2020]
 * @param {IPreventEffectsWrapper} wrapper
 * @returns {boolean}
 */
var selectPreventEffects = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.preventEffects;
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {boolean}
 */
var selectPreventEffectsFromAction = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : nvl_1.NvlUtils.coalesce(selectPreventEffects(wrapper.data), selectPreventEffects(wrapper.initialData));
};
/**
 * @stable [08.06.2020]
 * @param {IPreviousActionWrapper<TValue>} wrapper
 * @returns {IPreviousActionWrapper<TValue>}
 */
var selectPreviousAction = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.previousAction;
};
/**
 * @stable [08.05.2020]
 * @param {IReduxListHolderEntity} entity
 * @returns {boolean}
 */
var selectListProgress = function (entity) { return wrapper_1.WrapperUtils.inProgress(selectList(entity)); };
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} wrapper
 * @returns {IEffectsAction}
 */
var selectPreviousActionFromAction = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : nvl_1.NvlUtils.coalesce(selectPreviousAction(wrapper.data), selectPreviousAction(wrapper.initialData));
};
/**
 * @stable [26.03.2020]
 * @param {IEffectsAction} action
 * @returns {string}
 */
var selectPreviousActionTypeFromAction = function (action) {
    return cond_1.ConditionUtils.ifNotNilThanValue(selectPreviousActionFromAction(action), function (previousAction) { return previousAction.type; }, definitions_interface_1.UNDEF_SYMBOL);
};
/**
 * @stable [08.09.2020]
 * @param action
 */
var selectSectionFromAction = function (action) {
    return nvl_1.NvlUtils.nvl(cond_1.ConditionUtils.ifNotNilThanValue(action.data, function (data) { return data.section; }, definitions_interface_1.UNDEF_SYMBOL), cond_1.ConditionUtils.ifNotNilThanValue(action.initialData, function (initialData) { return initialData.section; }, definitions_interface_1.UNDEF_SYMBOL));
};
/**
 * @stable [27.07.2020]
 * @param entity
 */
var selectSelected = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.selected;
};
/**
 * @stable [21.07.2020]
 * @param {IEffectsAction} action
 * @returns {TEntity}
 */
exports.selectSelectedEntityFromAction = function (action) {
    return selectSelected(exports.selectData(action));
};
/**
 * @stable [21.07.2020]
 * @param {IEffectsAction} action
 * @returns {EntityIdT}
 */
exports.selectSelectedEntityIdFromAction = function (action) {
    return selectEntityId(exports.selectSelectedEntityFromAction(action));
};
/**
 * @stable [30.03.2020]
 * @param {IUserWrapper<TUser>} wrapper
 * @returns {TUser}
 */
var selectUser = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.user;
};
/**
 * @stable [18.09.2020]
 * @param wrapper
 */
var selectStack = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.stack;
};
/**
 * @stable [14.04.2020]
 * @param {INotificationWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
var selectNotification = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.notification;
};
/**
 * @stable [24.04.2020]
 * @param {IQueryWrapper} wrapper
 * @returns {string}
 */
var selectQuery = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.query; };
/**
 * @stable [14.04.2020]
 * @param {ILayoutWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
var selectLayout = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.layout;
};
/**
 * @stable [21.05.2020]
 * @param {IModeWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
var selectMode = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.mode;
};
/**
 * @stable [14.04.2020]
 * @param {IChannelWrapper<TEntity>} wrapper
 * @returns {TEntity}
 */
var selectChannel = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.channel;
};
/**
 * @stable [30.03.2020]
 * @param {ITransportWrapper<TTransport>} wrapper
 * @returns {TTransport}
 */
var selectTransport = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.transport;
};
/**
 * @stable [09.06.2020]
 * @param {IDictionariesWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectDictionaries = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.dictionaries;
};
/**
 * @stable [10.08.2020]
 * @param wrapper
 */
var selectSectionName = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.sectionName; };
/**
 * @stable [10.08.2020]
 * @param wrapper
 */
var selectProgress = function (wrapper) { return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.progress; };
/**
 * @stable [17.05.2020]
 * @param {ITabPanelWrapper<TTabPanel>} entity
 * @returns {TTabPanel}
 */
var selectTabPanel = function (entity) {
    return R.isNil(entity) ? definitions_interface_1.UNDEF : entity.tabPanel;
};
/**
 * @stable [08.05.2020]
 * @param {IReduxListHolderEntity<TEntity extends IEntity>} entity
 * @returns {TEntity}
 */
var selectListSelectedEntity = function (entity) {
    return selectSelected(selectList(entity));
};
/**
 * @stable [08.05.2020]
 * @param {IDirectionsWrapper<TValue>} wrapper
 * @returns {TValue}
 */
var selectDirections = function (wrapper) {
    return R.isNil(wrapper) ? definitions_interface_1.UNDEF : wrapper.directions;
};
/**
 * @stable [08.05.2020]
 * @param {IReduxListHolderEntity} entity
 * @returns {TRawData}
 */
var selectListRawData = function (entity) { return selectRawData(selectList(entity)); };
/**
 * @stable [01.08.2020]
 * @param entity
 */
var selectFormHolderEntityChanges = function (entity) {
    return exports.selectChanges(selectForm(entity));
};
/**
 * @stable [01.08.2020]
 * @param wrapper
 */
var selectActiveToolbarToolsFromDirtyWrapper = function (wrapper) {
    return R.isNil(wrapper)
        ? definitions_interface_1.UNDEF
        : (cond_1.ConditionUtils.orUndef(wrapper_1.WrapperUtils.isDirty(wrapper), function () { return [definition_1.ToolbarToolsEnum.FILTER]; }));
};
/**
 * @stable [07.05.2020]
 * @param {IReduxQueryFilterHolderEntity} entity
 * @returns {string}
 */
var selectQueryFilterEntityQuery = function (entity) {
    return selectQuery(selectQueryFilter(entity));
};
/**
 * @stable [18.09.2020]
 * @param entity
 */
var selectStackItemEntities = function (entity) { return selectStack(selectStack(entity)); };
/**
 * @stable [18.09.2020]
 * @param entity
 */
var selectFirstStackItemEntity = function (entity) {
    return cond_1.ConditionUtils.ifNotEmptyThanValue(selectStackItemEntities(entity), function (stackItemEntities) { return stackItemEntities[0]; });
};
/**
 * @stable [21.05.2020]
 * @param {IReduxLayoutHolderEntity} entity
 * @returns {LayoutModesEnum}
 */
var selectLayoutMode = function (entity) { return selectMode(selectLayout(entity)); };
/**
 * @stable [21.05.2020]
 * @param {IReduxLayoutHolderEntity} merged
 * @param {IReduxLayoutHolderEntity} original
 * @returns {LayoutModesEnum}
 */
var selectMergedLayoutMode = function (merged, original) {
    return nvl_1.NvlUtils.nvl(selectLayoutMode(merged), selectLayoutMode(original));
};
/**
 * @stable [06.05.2020]
 */
var Selectors = /** @class */ (function () {
    function Selectors() {
    }
    Selectors.activeToolbarToolsFromDirtyWrapper = selectActiveToolbarToolsFromDirtyWrapper; /* @stable [08.05.2020] */
    Selectors.activeValue = selectActiveValue; /* @stable [30.07.2020] */
    Selectors.changes = exports.selectChanges;
    Selectors.channel = selectChannel; /* @stable [12.06.2020] */
    Selectors.data = exports.selectData; /* @stable [19.05.2020] */
    Selectors.dictionaries = selectDictionaries; /* @stable [09.06.2020] */
    Selectors.directions = selectDirections; /* @stable [08.05.2020] */
    Selectors.element = selectElement; /* @stable [08.06.2020] */
    Selectors.entity = exports.selectEntity;
    Selectors.entityId = selectEntityId; /* @stable [31.07.2020] */
    Selectors.error = selectError; /* @stable [12.06.2020] */
    Selectors.filter = selectFilter;
    Selectors.firstStackItemEntity = selectFirstStackItemEntity; /* @stable [18.09.2020] */
    Selectors.form = selectForm; /* @stable [11.05.2020] */
    Selectors.formHolderEntityChanges = selectFormHolderEntityChanges; /* @stable [01.08.2020] */
    Selectors.layout = selectLayout; /* @stable [08.05.2020] */
    Selectors.layoutMode = selectLayoutMode; /* @stable [21.05.2020] */
    Selectors.list = selectList;
    Selectors.listProgress = selectListProgress; /* @stable [08.05.2020] */
    Selectors.listRawData = selectListRawData; /* @stable [08.05.2020] */
    Selectors.listSelectedEntity = selectListSelectedEntity; /* @stable [08.05.2020] */
    Selectors.mergedLayoutMode = selectMergedLayoutMode; /* @stable [21.05.2020] */
    Selectors.notification = selectNotification; /* @stable [12.06.2020] */
    Selectors.payloadFromAction = selectPayloadFromAction; /* @stable [08.06.2020] */
    Selectors.preventEffectsFromAction = selectPreventEffectsFromAction; /* @stable [08.06.2020] */
    Selectors.previousActionFromAction = selectPreviousActionFromAction; /* @stable [08.05.2020] */
    Selectors.previousActionTypeFromAction = selectPreviousActionTypeFromAction; /* @stable [08.05.2020] */
    Selectors.primaryFilter = selectPrimaryFilter; /* @stable [10.05.2020] */
    Selectors.progress = selectProgress; /* @stable [10.08.2020] */
    Selectors.query = selectQuery;
    Selectors.queryFilter = selectQueryFilter;
    Selectors.queryFilterEntityQuery = selectQueryFilterEntityQuery;
    Selectors.queue = selectQueue; /* @stable [09.06.2020] */
    Selectors.rawData = selectRawData; /* @stable [09.06.2020] */
    Selectors.secondaryFilter = selectSecondaryFilter; /* @stable [09.05.2020] */
    Selectors.sectionFromAction = selectSectionFromAction; /* @stable [08.09.2020] */
    Selectors.sectionName = selectSectionName;
    Selectors.selected = selectSelected; /* @stable [27.07.2020] */
    Selectors.selectedEntityFromAction = exports.selectSelectedEntityFromAction; /* @stable [21.07.2020] */
    Selectors.selectedEntityIdFromAction = exports.selectSelectedEntityIdFromAction; /* @stable [21.07.2020] */
    Selectors.stack = selectStack; /* @stable [21.05.2020] */
    Selectors.stackItemEntities = selectStackItemEntities; /* @stable [21.05.2020] */
    Selectors.tabPanel = selectTabPanel; /* @stable [17.05.2020] */
    Selectors.transport = selectTransport; /* @stable [12.06.2020] */
    Selectors.user = selectUser; /* @stable [09.06.2020] */
    return Selectors;
}());
exports.Selectors = Selectors;
//# sourceMappingURL=select.js.map