"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.TypeUtils = exports.asType = exports.isFn = exports.isDef = void 0;
var R = require("ramda");
var regexp_definition_interface_1 = require("../definition/regexp-definition.interface");
/**
 * @stable [02.10.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.isDef = function (value) { return !isUndef(value); };
/**
 * @stable [08.09.2020]
 * @param value
 */
var isUndef = function (value) { return typeof value === 'undefined'; };
/**
 * @stable [02.10.2019]
 * @param {AnyT} value
 * @returns {boolean}
 */
exports.isFn = function (value) { return typeof value === 'function'; };
/**
 * @stable [07.09.2020]
 * @param value
 */
var isNumber = function (value) { return typeof value === 'number' && !isNaN(value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var isNotNumber = function (value) { return !isNumber(value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var isPositiveNumber = function (value) { return isNumber(value) && value >= 0; };
/**
 * @stable [07.09.2020]
 * @param value
 */
var isPositiveNumberLike = function (value) { return regexp_definition_interface_1.RegexpConstants.POSITIVE_NUMBER.test("" + value); };
/**
 * @stable [08.09.2020]
 * @param value
 */
var isPositiveOrNegativeNumberLike = function (value) { return regexp_definition_interface_1.RegexpConstants.POSITIVE_OR_NEGATIVE_NUMBER.test("" + value); };
/**
 * @stable [07.09.2020]
 * @param value
 */
var isPositiveOrNegativeOptionalNumberLike = function (value) {
    return R.isNil(value) || isPositiveOrNegativeNumberLike(value);
};
/**
 * @stable [07.09.2020]
 * @param value
 */
var isPositiveOptionalNumberLike = function (value) {
    return R.isNil(value) || isPositiveNumberLike(value);
};
/**
 * @stable [08.09.2020]
 * @param value
 */
var isBoolean = function (value) { return typeof value === 'boolean'; };
/**
 * @stable [08.09.2020]
 * @param value
 */
var isString = function (value) { return typeof value === 'string'; };
/**
 * @stable [28.09.2020]
 * @param value
 */
var isEmpty = function (value) { return R.isEmpty(value); };
/**
 * @stable [28.09.2020]
 * @param value
 */
var isNotEmpty = function (value) { return !isEmpty(value); };
/**
 * @stable [08.09.2020]
 * @param value
 */
var isNotEmptyString = function (value) { return isString(value) && isNotEmpty(value); };
/**
 * @stable [28.09.2020]
 * @param value
 */
var isNotEmptyObject = function (value) { return isObject(value) && isNotEmpty(value); };
/**
 * @stable [29.08.2020]
 * @param v
 */
var isPrimitive = function (v) { return isNumber(v) || isString(v) || isBoolean(v); };
/**
 * @stable [29.08.2020]
 * @param v
 */
var isObject = function (v) { return Object.prototype.toString.call(v) === '[object Object]'; };
/**
 * @stable [29.08.2020]
 * @param v
 */
var isEvent = function (v) { return v instanceof Event; };
/**
 * @stable [06.12.2018]
 * @param {TResult} result
 * @returns {TResult}
 */
exports.asType = function (result) { return result; };
/**
 * @stable [16.05.2020]
 */
var TypeUtils = /** @class */ (function () {
    function TypeUtils() {
    }
    TypeUtils.asType = exports.asType; /* @stable [08.09.2020] */
    TypeUtils.isBoolean = isBoolean; /* @stable [12.06.2020] */
    TypeUtils.isDef = exports.isDef; /* @stable [16.05.2020] */
    TypeUtils.isEvent = isEvent; /* @stable [29.08.2020] */
    TypeUtils.isFn = exports.isFn; /* @stable [16.05.2020] */
    TypeUtils.isNotEmptyObject = isNotEmptyObject; /* @stable [28.09.2020] */
    TypeUtils.isNotEmptyString = isNotEmptyString; /* @stable [08.09.2020] */
    TypeUtils.isNotNumber = isNotNumber; /* @stable [07.09.2020] */
    TypeUtils.isNumber = isNumber; /* @stable [16.05.2020] */
    TypeUtils.isObject = isObject; /* @stable [16.05.2020] */
    TypeUtils.isPositiveNumber = isPositiveNumber; /* @stable [07.09.2020] */
    TypeUtils.isPositiveNumberLike = isPositiveNumberLike; /* @stable [07.09.2020] */
    TypeUtils.isPositiveOptionalNumberLike = isPositiveOptionalNumberLike; /* @stable [07.09.2020] */
    TypeUtils.isPositiveOrNegativeNumberLike = isPositiveOrNegativeNumberLike; /* @stable [22.07.2020] */
    TypeUtils.isPositiveOrNegativeOptionalNumberLike = isPositiveOrNegativeOptionalNumberLike; /* @stable [07.09.2020] */
    TypeUtils.isPrimitive = isPrimitive; /* @stable [16.05.2020] */
    TypeUtils.isString = isString; /* @stable [16.05.2020] */
    TypeUtils.isUndef = isUndef; /* @stable [16.05.2020] */
    return TypeUtils;
}());
exports.TypeUtils = TypeUtils;
//# sourceMappingURL=type.js.map